@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with SIDEKIT.  If not, see <http://www.gnu.org/licenses/>.
 """
-Copyright 2014-2019 Sylvain Meignier and Anthony Larcher
+Copyright 2014-2021 Sylvain Meignier and Anthony Larcher
 
     :mod:`factor_analyser` provides methods to train different types of factor analysers
 
@@ -42,7 +42,7 @@ from sidekit import STAT_TYPE
 
 __license__ = "LGPL"
 __author__ = "Anthony Larcher & Sylvain Meignier"
-__copyright__ = "Copyright 2014-2019 Anthony Larcher"
+__copyright__ = "Copyright 2014-2021 Anthony Larcher"
 __maintainer__ = "Anthony Larcher"
 __email__ = "anthony.larcher@univ-lemans.fr"
 __status__ = "Production"
@@ -833,7 +833,8 @@ class FactorAnalyser:
              scaling_factor=1.,
              output_file_name=None,
              save_partial=False,
-             save_final=True):
+             save_final=True,
+             num_thread=1):
         """
         Train a simplified Probabilistic Linear Discriminant Analysis model (no within class covariance matrix
         but full residual covariance matrix)
@@ -904,7 +905,7 @@ class FactorAnalyser:
                           stat1=local_stat.stat1,
                           e_h=e_h,
                           e_hh=e_hh,
-                          num_thread=1)
+                          num_thread=num_thread)
 
             # Accumulate for minimum divergence step
             _R = numpy.sum(e_hh, axis=0) / session_per_model.shape[0]
