@@ -21,7 +21,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with SIDEKIT.  If not, see <http://www.gnu.org/licenses/>.
 """
-Copyright 2014-2020 Sylvain Meignier and Anthony Larcher
+Copyright 2014-2021 Sylvain Meignier and Anthony Larcher
 
     :mod:`features_server` provides methods to manage features
 
@@ -44,7 +44,7 @@ from .bosaris import IdMap
 
 __license__ = "LGPL"
 __author__ = "Anthony Larcher & Sylvain Meignier"
-__copyright__ = "Copyright 2014-2020 Anthony Larcher"
+__copyright__ = "Copyright 2014-2021 Anthony Larcher"
 __maintainer__ = "Anthony Larcher"
 __email__ = "anthony.larcher@univ-lemans.fr"
 __status__ = "Production"
@@ -308,7 +308,7 @@ class FeaturesExtractor(object):
         # Create the HDF5 file
         # Create the directory if it dosn't exist
         dir_name = os.path.dirname(feature_filename)  # get the path
-        if not os.path.exists(dir_name) and (dir_name is not ''):
+        if not os.path.exists(dir_name) and not (dir_name == ''):
             os.makedirs(dir_name) 
 
         h5f = h5py.File(feature_filename, 'a', backing_store=backing_store, driver='core')
@@ -496,7 +496,7 @@ class FeaturesExtractor(object):
         feature_filename = feature_filename_structure.format(show)
         logging.info('output finename: '+feature_filename)
         dir_name = os.path.dirname(feature_filename)  # get the path
-        if not os.path.exists(dir_name) and (dir_name is not ''):
+        if not os.path.exists(dir_name) and not (dir_name == ''):
             os.makedirs(dir_name)
 
         h5f = h5py.File(feature_filename, 'a', backing_store=True, driver='core')
